==> cobalt-0.0.1-sources.jar: it/auties/whatsapp/model/button/template/hsm/HighlyStructuredButtonTemplateBuilder.java <==
package it.auties.whatsapp.model.button.template.hsm;

public class HighlyStructuredButtonTemplateBuilder {
    private java.util.Optional<it.auties.whatsapp.model.button.template.hsm.HighlyStructuredQuickReplyButton> highlyStructuredQuickReplyButton;
    private java.util.Optional<it.auties.whatsapp.model.button.template.hsm.HighlyStructuredURLButton> highlyStructuredUrlButton;
    private java.util.Optional<it.auties.whatsapp.model.button.template.hsm.HighlyStructuredCallButton> highlyStructuredCallButton;
    private int index;

    public HighlyStructuredButtonTemplateBuilder() {
        highlyStructuredQuickReplyButton = java.util.Optional.empty();
        highlyStructuredUrlButton = java.util.Optional.empty();
        highlyStructuredCallButton = java.util.Optional.empty();
        index = 0;
    }

    public HighlyStructuredButtonTemplateBuilder highlyStructuredQuickReplyButton(java.util.Optional<it.auties.whatsapp.model.button.template.hsm.HighlyStructuredQuickReplyButton> highlyStructuredQuickReplyButton) {
        this.highlyStructuredQuickReplyButton = highlyStructuredQuickReplyButton;
        return this;
    }
    public HighlyStructuredButtonTemplateBuilder highlyStructuredQuickReplyButton(it.auties.whatsapp.model.button.template.hsm.HighlyStructuredQuickReplyButton highlyStructuredQuickReplyButton) {
        this.highlyStructuredQuickReplyButton = java.util.Optional.ofNullable(highlyStructuredQuickReplyButton);
        return this;
    }
    public HighlyStructuredButtonTemplateBuilder highlyStructuredUrlButton(java.util.Optional<it.auties.whatsapp.model.button.template.hsm.HighlyStructuredURLButton> highlyStructuredUrlButton) {
        this.highlyStructuredUrlButton = highlyStructuredUrlButton;
        return this;
    }
    public HighlyStructuredButtonTemplateBuilder highlyStructuredUrlButton(it.auties.whatsapp.model.button.template.hsm.HighlyStructuredURLButton highlyStructuredUrlButton) {
        this.highlyStructuredUrlButton = java.util.Optional.ofNullable(highlyStructuredUrlButton);
        return this;
    }
    public HighlyStructuredButtonTemplateBuilder highlyStructuredCallButton(java.util.Optional<it.auties.whatsapp.model.button.template.hsm.HighlyStructuredCallButton> highlyStructuredCallButton) {
        this.highlyStructuredCallButton = highlyStructuredCallButton;
        return this;
    }
    public HighlyStructuredButtonTemplateBuilder highlyStructuredCallButton(it.auties.whatsapp.model.button.template.hsm.HighlyStructuredCallButton highlyStructuredCallButton) {
        this.highlyStructuredCallButton = java.util.Optional.ofNullable(highlyStructuredCallButton);
        return this;
    }
    public HighlyStructuredButtonTemplateBuilder index(int index) {
        this.index = index;
        return this;
    }

    public it.auties.whatsapp.model.button.template.hsm.HighlyStructuredButtonTemplate build() {
        return new it.auties.whatsapp.model.button.template.hsm.HighlyStructuredButtonTemplate(highlyStructuredQuickReplyButton, highlyStructuredUrlButton, highlyStructuredCallButton, index);
    }
}

==> cobalt-0.0.7-sources.jar: it/auties/whatsapp/model/button/template/hsm/HighlyStructuredButtonTemplateBuilder.java <==
package it.auties.whatsapp.model.button.template.hsm;

public class HighlyStructuredButtonTemplateBuilder {
    private java.util.Optional<it.auties.whatsapp.model.button.template.hsm.HighlyStructuredQuickReplyButton> highlyStructuredQuickReplyButton;
    private java.util.Optional<it.auties.whatsapp.model.button.template.hsm.HighlyStructuredURLButton> highlyStructuredUrlButton;
    private java.util.Optional<it.auties.whatsapp.model.button.template.hsm.HighlyStructuredCallButton> highlyStructuredCallButton;
    private int index;

    public HighlyStructuredButtonTemplateBuilder() {
        highlyStructuredQuickReplyButton = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        highlyStructuredUrlButton = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        highlyStructuredCallButton = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        index = 0;
    }

    public HighlyStructuredButtonTemplateBuilder highlyStructuredQuickReplyButton(it.auties.whatsapp.model.button.template.hsm.HighlyStructuredQuickReplyButton highlyStructuredQuickReplyButton) {
        this.highlyStructuredQuickReplyButton = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(highlyStructuredQuickReplyButton);
        return this;
    }

    public HighlyStructuredButtonTemplateBuilder highlyStructuredUrlButton(it.auties.whatsapp.model.button.template.hsm.HighlyStructuredURLButton highlyStructuredUrlButton) {
        this.highlyStructuredUrlButton = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(highlyStructuredUrlButton);
        return this;
    }

    public HighlyStructuredButtonTemplateBuilder highlyStructuredCallButton(it.auties.whatsapp.model.button.template.hsm.HighlyStructuredCallButton highlyStructuredCallButton) {
        this.highlyStructuredCallButton = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(highlyStructuredCallButton);
        return this;
    }

    public HighlyStructuredButtonTemplateBuilder index(int index) {
        this.index = index;
        return this;
    }

    public it.auties.whatsapp.model.button.template.hsm.HighlyStructuredButtonTemplate build() {
        return new it.auties.whatsapp.model.button.template.hsm.HighlyStructuredButtonTemplate(highlyStructuredQuickReplyButton, highlyStructuredUrlButton, highlyStructuredCallButton, index);
    }

}
